create.bbox: create.bbox

View source: R/create.bbox.R

create.bboxR Documentation

create.bbox

Description

create a SpatialPolygonsDataFrame from the bounding box coordinates of a shapefile

Usage

create.bbox(inshape, id, buffer = TRUE, buffsize = 1, native = TRUE)

Arguments

inshape

input shapefile to create bounding box around

id

character of id for bounding box

buffer

Logical. If TRUE (default), create new shapefile with a specified buffer around it

buffsize

numeric vector of number of kilometers to buffer around bounding box

native

Logical. If TRUE (default), return shapefile in the native projection, if FALSE, return shapefile in the Albers Equal Area (used to create buffer)

Value

Returns a SpatialPolygonsDataFrame with bounding box with buffer if buffer = TRUE


khuggler/Ovis documentation built on Nov. 30, 2023, 7:41 p.m.