extract.terra.climate: extract.terra.climate

View source: R/extract.terra.climate.R

extract.terra.climateR Documentation

extract.terra.climate

Description

extract locations of composition plots to terraclimate data

Usage

extract.terra.climate(root.dir, cropshape, months, comp.data, sub.dir,
  years, out.dir)

Arguments

root.dir

path of root directory where TerraClimate data are stored

cropshape

path to shapefile to crop TerraClimate data

months

numeric vector of months needed from TerraClimate data ex) c(6,7,8,9)

comp.data

path to composition database

sub.dir

directory name of where intermediate .RDS files should be saved. Should be directory that is different from root.dir

years

vectory of years YYYY for extraction

out.dir

path to directory of where extracted data should be saved

Value

Returns a csv of extracted data for all TerraClimater layers


khuggler/Ovis documentation built on Nov. 30, 2023, 7:41 p.m.