| create.bbox | R Documentation |
create a SpatialPolygonsDataFrame from the bounding box coordinates of a shapefile
create.bbox(inshape, id, buffer = TRUE, buffsize = 1, native = TRUE)
inshape |
input shapefile to create bounding box around |
id |
character of id for bounding box |
buffer |
Logical. If TRUE (default), create new shapefile with a specified buffer around it |
buffsize |
numeric vector of number of kilometers to buffer around bounding box |
native |
Logical. If TRUE (default), return shapefile in the native projection, if FALSE, return shapefile in the Albers Equal Area (used to create buffer) |
Returns a SpatialPolygonsDataFrame with bounding box with buffer if buffer = TRUE
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.