View source: R/extract.terra.climate.R
| extract.terra.climate | R Documentation |
extract locations of composition plots to terraclimate data
extract.terra.climate(root.dir, cropshape, months, comp.data, sub.dir,
years, out.dir)
root.dir |
path of root directory where TerraClimate data are stored |
cropshape |
path to shapefile to crop TerraClimate data |
months |
numeric vector of months needed from TerraClimate data ex) c(6,7,8,9) |
comp.data |
path to composition database |
sub.dir |
directory name of where intermediate .RDS files should be saved. Should be directory that is different from root.dir |
years |
vectory of years YYYY for extraction |
out.dir |
path to directory of where extracted data should be saved |
Returns a csv of extracted data for all TerraClimater layers
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.