| sheep.gps | R Documentation |
Scrape GPS data from online server, and merge with downloaded data from collars
sheep.gps(
keys,
sheepdb,
collarhistory,
tzone,
capcol,
dateformat,
mortcol,
dnld.data,
dnld.fold,
extracols
)
keys |
full path to one or more key files |
sheepdb |
path to sheep capture database |
collarhistory |
path to collar history file |
tzone |
desired time zone of gps data: "MST" or "US/Pacific" |
capcol |
name of column where capture/start date exists |
dateformat |
character string of the format that date columns are in |
mortcol |
name of column where mortality date or end date exists |
dnld.data |
Logical. TRUE/FALSE whether to include downloaded data from collars |
dnld.fold |
path to root folder where downloaded data exists |
extracols |
vector of extra columns that should be appended to GPS data. Names in vector MUST match names in lookup table |
Returns a data.frame with all gps data and any extra columns desired
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.